==> 0.0.9.tar.gz: lib/API/PIA_API_Widget.dart <==

import 'dart:convert';

import 'package:dio/dio.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:pia_framework_base/Func/PIA_Func.dart';
import 'package:pia_framework_base/Variable/PIA_Global.dart';
import 'package:pia_framework_base/Lang/PIA_Lang.dart';


class PIA_API_Widget extends StatefulWidget
{  final String url;
   final Map<String,String> post;
   final PIA_API_CallBack callback;

   const PIA_API_Widget({ Key key,this.url,this.post,this.callback}) : super(key: key);
   _PIA_API_Widget_State createState()=>_PIA_API_Widget_State();
}


// #docregion print-state
class _PIA_API_Widget_State extends State<PIA_API_Widget> {
  var error_title = "";
  var error_message = "";
  final CancelToken token = new CancelToken();

  @override
  void initState()
    { super.initState();
      print("API Widget init");
      error_title = "";
      error_message = "";
      _dio_post();
    }

  @override
  void dispose() {
    super.dispose();
    token.cancel();
    print("API Widget dispose");
  }

  @override
  void didChangeDependencies() {
    print("API Widget didChangeDependencies");
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    print("API Widget didChangeDependencie:" + state.toString());
  }

  @override
  Widget build(BuildContext context) {
    print("API Widget Build :$error_message");
    // TODO: implement build
     if(error_message.isEmpty) {
       return Center(
           child: SizedBox(
               child:
               new CircularProgressIndicator(
                   valueColor: new AlwaysStoppedAnimation(Colors.blue),
                   strokeWidth: 5.0),
               height: 40.0,
               width: 40.0));
     }
     else
       return Center(
       child:Padding(
       padding: EdgeInsets.all(10),
       child:Column(
       mainAxisAlignment: MainAxisAlignment.center,
       crossAxisAlignment: CrossAxisAlignment.center,
       children: <Widget>[
       Text(error_title,style:TextStyle(color:Colors.red,fontSize: 15 )),
       SizedBox(height: 5,),
       Text(error_message,style:TextStyle(color:Colors.black,fontSize: 14,), textAlign: TextAlign.center,),
       SizedBox(height: 10,),
       RaisedButton(child:Text(api_retry[PIA_Lang.lang_id]),

       onPressed: (){
           setState(() {
             error_message = "";
             _dio_post();
           });
         },
       )
     ],)));
  }

  void _dio_post() async
  {    var network = await PIA_Func.Check_network();
       if(!network) {
         setState(() {
           print("Cannot connect 沒有網際網路連線");
           error_message = api_nonetwork[PIA_Lang.lang_id];
           error_title = "";
         });
         return;
       }



  Dio dio = new Dio();
    dio.options.connectTimeout = connectTimeout;
    dio.options.receiveTimeout = receiveTimeout;
    print("Post " + widget.url + " Post:" + widget.post.toString());


    Response response = await dio.post(
      widget.url,
      data: new FormData.from(widget.post == null ? Map<String,String>(): widget.post),
      cancelToken: token,
      onSendProgress: (int sent, int total) {
        print(" $sent $total");
      },
    ).catchError((err) {
      DioError error = err;
      if(error.type == DioErrorType.CANCEL) {
        print("API Widget Cancel");
        return;
      }

      print("Catch Error " + error.message);
      print("Error type ");
      print(error.type);

      if (this.mounted){
      setState(() {

        if (error.type == DioErrorType.DEFAULT) {
          error_title = api_link_error[PIA_Lang.lang_id];
          error_message = widget.url;

          if(error.message.contains("FormatException"))
          {   error_title = api_program_error[PIA_Lang.lang_id];
              error_message = widget.url + "\n\n" + error.message; }
          if(error.message.contains("HttpException"))
          {  error_message = api_nonetwork[PIA_Lang.lang_id];
              error_title = ""; }
        }



        if (error.type == DioErrorType.RESPONSE) {
          error_title = api_link_error[PIA_Lang.lang_id];
          error_message = widget.url;
        }

        if (error.type == DioErrorType.CONNECT_TIMEOUT) {
          print("Cannot connect 沒有網際網路連線");
          error_message = api_nonetwork[PIA_Lang.lang_id];
          error_title = "";
        }

        if (error.type == DioErrorType.RECEIVE_TIMEOUT) {
          print("Error TimeOut");
          error_message = api_connect_error_slow[PIA_Lang.lang_id];
          error_title = "";
        }
       }); }
       return;
    });

    print("Mount ${this.mounted}");
    if (this.mounted) {
    if (response != null && response.statusCode == 200) {
      print(response.toString());
      print("status :" + response.statusCode.toString());

      var js = jsonDecode(response.toString());
      if (js["status"] == 0 && js["err_message"]
          .toString()
          .isNotEmpty) {
        setState(() {
          error_title = api_error[PIA_Lang.lang_id];
          error_message = js["err_message"].toString();
        });
      }
      else {
        print("Goto Callback " + widget.callback.toString());

        if (widget.callback != null) {
          widget.callback.API_Success(js["sdata"], js["data"]);
        }
      }

    }}

  }
}

==> 1.15.2.tar.gz: lib/API/PIA_API_Widget.dart <==

import 'dart:convert';

import 'package:dio/dio.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:pia_framework_base/Func/PIA_Func.dart';
import 'package:pia_framework_base/Variable/PIA_Global.dart';
import 'package:pia_framework_base/Lang/PIA_Lang.dart';


class PIA_API_Widget extends StatefulWidget
{  final String url;
   final Map<String,String> post;
   final PIA_API_CallBack callback;

   const PIA_API_Widget({ Key key,this.url,this.post,this.callback}) : super(key: key);
   _PIA_API_Widget_State createState()=>_PIA_API_Widget_State();
}


// #docregion print-state
class _PIA_API_Widget_State extends State<PIA_API_Widget> {
  var error_title = "";
  var error_message = "";
  final CancelToken token = new CancelToken();

  @override
  void initState()
    { super.initState();
      print("API Widget init");
      error_title = "";
      error_message = "";
      _dio_post();
    }

  @override
  void dispose() {
    super.dispose();
    token.cancel();
    print("API Widget dispose");
  }

  @override
  void didChangeDependencies() {
    print("API Widget didChangeDependencies");
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    print("API Widget didChangeDependencie:" + state.toString());
  }

  @override
  Widget build(BuildContext context) {
    print("API Widget Build :$error_message");
    // TODO: implement build
     if(error_message.isEmpty) {
       return Center(
           child: SizedBox(
               child:
               new CircularProgressIndicator(
                   valueColor: new AlwaysStoppedAnimation(Colors.blue),
                   strokeWidth: 5.0),
               height: 40.0,
               width: 40.0));
     }
     else
       return Center(
       child:Padding(
       padding: EdgeInsets.all(10),
       child:Column(
       mainAxisAlignment: MainAxisAlignment.center,
       crossAxisAlignment: CrossAxisAlignment.center,
       children: <Widget>[
       Text(error_title,style:TextStyle(color:Colors.red,fontSize: 15 )),
       SizedBox(height: 5,),
       Text(error_message,style:TextStyle(color:Colors.black,fontSize: 14,), textAlign: TextAlign.center,),
       SizedBox(height: 10,),
       RaisedButton(child:Text(api_retry[PIA_Lang.lang_id]),

       onPressed: (){
           setState(() {
             error_message = "";
             _dio_post();
           });
         },
       )
     ],)));
  }

  void _dio_post() async
  {    var network = await PIA_Func.Check_network();
       if(!network) {
         setState(() {
           print("Cannot connect 沒有網際網路連線");
           error_message = api_nonetwork[PIA_Lang.lang_id];
           error_title = "";
         });
         return;
       }



  Dio dio = new Dio();
    dio.options.connectTimeout = connectTimeout;
    dio.options.receiveTimeout = receiveTimeout;
    print("Post " + widget.url + " Post:" + widget.post.toString());


    Response response = await dio.post(
      widget.url,
      data: new FormData.fromMap(widget.post == null ? Map<String,String>(): widget.post),
      cancelToken: token,
      onSendProgress: (int sent, int total) {
        print(" $sent $total");
      },
    ).catchError((err) {
      DioError error = err;
      if(error.type == DioErrorType.CANCEL) {
        print("API Widget Cancel");
        return;
      }

      print("Catch Error " + error.message);
      print("Error type ");
      print(error.type);

      if (this.mounted){
      setState(() {

        if (error.type == DioErrorType.DEFAULT) {
          error_title = api_link_error[PIA_Lang.lang_id];
          error_message = widget.url;

          if(error.message.contains("FormatException"))
          {   error_title = api_program_error[PIA_Lang.lang_id];
              error_message = widget.url + "\n\n" + error.message; }
          if(error.message.contains("HttpException"))
          {  error_message = api_nonetwork[PIA_Lang.lang_id];
              error_title = ""; }
        }



        if (error.type == DioErrorType.RESPONSE) {
          error_title = api_link_error[PIA_Lang.lang_id];
          error_message = widget.url;
        }

        if (error.type == DioErrorType.CONNECT_TIMEOUT) {
          print("Cannot connect 沒有網際網路連線");
          error_message = api_nonetwork[PIA_Lang.lang_id];
          error_title = "";
        }

        if (error.type == DioErrorType.RECEIVE_TIMEOUT) {
          print("Error TimeOut");
          error_message = api_connect_error_slow[PIA_Lang.lang_id];
          error_title = "";
        }
       }); }
       return;
    });

    print("Mount ${this.mounted}");
    if (this.mounted) {
    if (response != null && response.statusCode == 200) {
      print(response.toString());
      print("status :" + response.statusCode.toString());

      var js = jsonDecode(response.toString());
      if (js["status"] == 0 && js["err_message"]
          .toString()
          .isNotEmpty) {
        setState(() {
          error_title = api_error[PIA_Lang.lang_id];
          error_message = js["err_message"].toString();
        });
      }
      else {
        print("Goto Callback " + widget.callback.toString());

        if (widget.callback != null) {
          widget.callback.API_Success(js["sdata"], js["data"]);
        }
      }

    }}

  }
}
